#
# spec file for package python-Yapsy
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-Yapsy
Version:        1.11.223
Release:        lp151.2.3
Summary:        Yet another plugin system
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            http://yapsy.sourceforge.net
Source:         https://files.pythonhosted.org/packages/source/Y/Yapsy/Yapsy-1.11.223.tar.gz
# PATCH-FIX-OPENSUSE fix-file-location-test.patch sebix+novell.com@sebix.at -- Fix file locations for tests
Patch0:         fix-file-location-test.patch
# PATCH-FIX-OPENSUSE fix-error-plugin-test.patch sebix+novell.com@sebix.at -- Fix exception class for tests
Patch1:         fix-error-plugin-test.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION docs
BuildRequires:  python-Sphinx
# /SECTION
Provides:       python-yapsy
Suggests:       %{name}-doc
BuildArch:      noarch

%{python_subpackages}

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML

%description
Yapsy is a small library implementing the core mechanisms needed to
build a plugin system into a wider application.

The main purpose is to depend only on Python's standard libraries (at
least version 2.3) and to implement only the basic functionalities
needed to detect, load and keep track of several plugins.

%description -n %{name}-doc
HTML documentation files for %{name}.

%prep
%setup -q -n Yapsy-%{version}
%patch0
%patch1

%build
%{python_build}
find yapsy/ -name "*.py" -exec sed -i -e  '/^#!\s\?\/usr\/bin\/\(env\s\)\?python$/d' {} ';'
pushd doc
make html
#rm _build/html/.buildinfo
popd

%install
%{python_install}
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%if %{with test}
%check
%{python_exec setup.py test}
%endif

%files %{python_files}
%{python_sitelib}/*
%doc CHANGELOG.txt README.txt
%license LICENSE.txt

%files -n %{name}-doc
%doc doc/_build/html
%doc artwork

%changelog
* Sat Jul 22 2017 sebix+novell.com@sebix.at
- convert to singlespec
- run tests during build
  * add fix-file-location-test.patch to fix a hardcoded path in the tests
  * add fix-error-plugin-test.patch to fix test on 3.6
- add documentation in subpackage python-Yapsy-doc
* Fri Jan  6 2017 boris@steki.net
- updated to version 1.11.223
- code: Make _extractCorePluginInfo accept Unicode filenames
  (bug https://sourceforge.net/p/yapsy/bugs/30/)
- code: fix default change trigger for ConfigurablePluginManager
  (see https://sourceforge.net/p/yapsy/support-requests/9/)
- code: merge python3 and default branch (contrib delijati)
- code: fix exception catching to support flask use case
  (contrib delijati: https://github.com/tibonihoo/yapsy/pull/4)
- code: fix error reporting (contrib frmdstryr:
  https://github.com/tibonihoo/yapsy/pull/5)
- code: allow plugins to run in separate processes
  (contrib pylanglois: https://github.com/tibonihoo/yapsy/pull/6)
- code: fix dangerous usage of mutable objects as default arguments
- doc: added an example of fetching yapsy's development version with pip
- code: Speed optimisation for the regexp compiled in __init__.py
  (see https://sourceforge.net/p/yapsy/patches/4/)
- code: fix bug "Plugin detection doesn't follow symlinks"
  (see https://sourceforge.net/p/yapsy/bugs/19/)
- doc: add links to coveralls.io for code coverage
- code: fix PluginInfo properties
  (see https://sourceforge.net/p/yapsy/bugs/13/)
- code: fix ConfigurablePluginManager.loadplugin ignore callback
  bug reported at https://sourceforge.net/p/yapsy/bugs/17/
- code: small improvement to the parse error handling
  (related to https://sourceforge.net/p/yapsy/bugs/12/)
- packaging: version name change to comply with PEP440 and resolve pip install problems.
- code: fix compatibility with python2.5
- code: fix compatibility with python2.5
- doc: add links to travis-ci and readthedocs.org
- code: fix AutoInstall test failures [contrib. Agustin Henze]
- code: replace deprecated methods usage (for Python3)
- code: switch from exec to imp.load_module for plugin loading
  which also solves https://sourceforge.net/p/yapsy/bugs/9/
- doc: add explanation about plugin class detection caveat
  https://sourceforge.net/p/yapsy/bugs/8/
- code: fix unicode bug on python2 version,
  see https://sourceforge.net/p/yapsy/bugs/10/
- code: [contrib. Mathieu Havel] "plugin locators" allow to change the
  strategy to describe and locate plugins
- code: [contrib. Mathieu Clabaut] multiple categories per plugin
  (cf https://bitbucket.org/matclab/yapsy-mcl)
- code: [contrib.  Mark Fickett] improve logging
- code: Gather detailed information on plugin load error via a callback
- code: Extra info to plug-in (eg add extra section or embed the ConfigParser
  output to the plugin_info), see also https://github.com/tintinweb/yapsy
- code: proper config of the default "plugin locator" can stop plugin
  detection from scanning a directory recursively
- code: Enforce a same tab convention everywhere
- doc: update list of project using yapsy
- doc: highlight the existence of tutorial and link to these ones:
- doc: be more helpful to users with an advice/troubleshooting page
- doc: add a CHANGELOG.txt file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Apr  2 2013 boris@steki.net
- initial packaging of version 1.9.2
